@@ -5,7 +5,7 @@ import warnings
 from dataclasses import dataclass, field
 from datetime import datetime, timedelta
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Union
 
 import pydantic
 
@@ -24,6 +24,10 @@ class ParsingError(Exception):
     pass
 
 
+class ClientNotFoundError(Exception):
+    pass
+
+
 class Command(list):
     def add_simple_arg(self, name: str, value: Any):
         if value is not None:
@@ -58,12 +62,25 @@ class ClientConfig:
     compose_profiles: List[str] = field(default_factory=list)
     compose_env_file: Optional[ValidPath] = None
     compose_project_name: Optional[str] = None
+    compose_project_directory: Optional[ValidPath] = None
     compose_compatibility: Optional[bool] = None
+    client_call: List[str] = field(default_factory=lambda: ["docker"])
+    _client_call_with_path: Optional[List[Union[Path, str]]] = None
 
-    def get_docker_path(self) -> ValidPath:
-        if self.client_binary_path is None:
-            self.client_binary_path = get_docker_client_binary_path()
-            if self.client_binary_path is None:
+    def get_client_call_with_path(self) -> List[Union[Path, str]]:
+        if self._client_call_with_path is None:
+            self._client_call_with_path = [
+                Path(self._get_docker_path())
+            ] + self.client_call[1:]
+
+        return self._client_call_with_path
+
+    def _get_docker_path(self) -> str:
+        which_result = shutil.which(self.client_call[0])
+        if which_result is not None:
+            return which_result
+        if self.client_call[0] == "docker":
+            if not get_docker_binary_path_in_cache().exists():
                 warnings.warn(
                     "The docker client binary file was not found on your system. \n"
                     "Docker on whales will try to download it for you. \n"
@@ -79,13 +96,18 @@ class ClientConfig:
                     "$ python-on-whales download-cli \n"
                 )
                 download_docker_cli()
-                self.client_binary_path = get_docker_binary_path_in_cache()
-        return self.client_binary_path
+            return get_docker_binary_path_in_cache()
+
+        raise ClientNotFoundError(
+            f"The binary '{self.client_call[0]}' could not be found on your PATH. "
+            f"Please ensure that your PATH is has the directory of the binary you're looking for. "
+            f"You can use `print(os.environ['PATH'])` to verify what directories are in your PATH."
+        )
 
     @property
     def docker_cmd(self) -> Command:
 
-        result = Command([self.get_docker_path()])
+        result = Command(self.get_client_call_with_path())
 
         if self.config is not None:
             result += ["--config", self.config]
@@ -126,6 +148,7 @@ class ClientConfig:
         base_cmd.add_args_list("--profile", self.compose_profiles)
         base_cmd.add_simple_arg("--env-file", self.compose_env_file)
         base_cmd.add_simple_arg("--project-name", self.compose_project_name)
+        base_cmd.add_simple_arg("--project-directory", self.compose_project_directory)
         base_cmd.add_flag("--compatibility", self.compose_compatibility)
         return base_cmd
 
@@ -244,23 +267,3 @@ def bulk_reload(docker_objects: List[ReloadableObjectFromJson]):
     json_str = run(full_cmd)
     for json_obj, docker_object in zip(json.loads(json_str), docker_objects):
         docker_object._set_inspect_result(docker_object._parse_json_object(json_obj))
-
-
-def get_docker_client_binary_path() -> Optional[Path]:
-    """Return the path of the docker client binary file.
-    If `None` is returned, the docker client binary is not available and must be downloaded.
-
-    # Returns
-        `Optional[Path]`, The path of the docker client binary file.
-
-    Note that if you use python-on-whales normally, the docker client binary is
-    downloaded automatically if needed. So you only need this function if you
-    want to bypass the automatic download process.
-    """
-    docker_sys = shutil.which("docker")
-    if docker_sys is not None:
-        return Path(docker_sys)
-    elif get_docker_binary_path_in_cache().exists():
-        return get_docker_binary_path_in_cache()
-    else:
-        return None
